@@ -52,6 +52,8 @@ class QLDemo:
                 r = self.parse_servercommand()
             elif cmd == SVC_SNAPSHOT:
                 r = self.parse_snapshot()
+                if len(self.snapshots) and r.serverTime == self.snapshots[-1].serverTime:
+                    raise StopIteration
                 self.snapshots.append(r)
             self.packets.append(r)
             if r: yield r
@@ -150,16 +152,16 @@ class QLDemo:
         string = huffman.readstring()
         
         sc=ServerCommand(seq, string)
-        if sc.cmd == "scores_duel":
-            sc = self.parse_duel_scores(sc)
-            self.scores.append(sc.scores)
-        elif sc.cmd == "scores_ctf":
-            sc = self.parse_ctf_scores(sc)
-            self.scores.append(sc.scores)
-        elif sc.cmd == "scores":
-            sc = self.parse_old_scores(sc)
-            self.scores.append(sc.scores)
-        elif sc.cmd == 'cs' or sc.cmd == 'bcs':
+        #if sc.cmd == "scores_duel":
+        #    sc = self.parse_duel_scores(sc)
+        #    self.scores.append(sc.scores)
+        #elif sc.cmd == "scores_ctf":
+        #    sc = self.parse_ctf_scores(sc)
+        #    self.scores.append(sc.scores)
+        #elif sc.cmd == "scores":
+        #    sc = self.parse_old_scores(sc)
+        #    self.scores.append(sc.scores)
+        if sc.cmd == 'cs' or sc.cmd == 'bcs':
             self.update_configstring(sc)
         return sc
 
@@ -310,9 +312,9 @@ class QLDemo:
     def parse_snapshot(self):
         new_snap = Snapshot()
         new_snap.serverTime=huffman.readlong()
-        delta_num = huffman.readbyte()
-        new_snap.snapFlags = huffman.readbyte()
-        new_snap.areamaskLen = huffman.readbyte()
+        #delta_num = huffman.readbyte()
+        #new_snap.snapFlags = huffman.readbyte()
+        #new_snap.areamaskLen = huffman.readbyte()
         #for i in range(new_snap.areamaskLen+1):
         #    new_snap.areamask.append(huffman.readbyte())
         #ps = self.parse_playerstate()
